==> paykeeper1.5.1_bitrix18-25_rev2.zip: bitrix/modules/sale/handlers/paysystem/paykeeper/lang/ru/.description.php <==
<?php
global $MESS;
$MESS["SALE_HPS_PAYKEEPER_SETTINGS"] = "Настройки подключения PayKeeper";
$MESS["SALE_HPS_PAYKEEPER_FORM_URL"] = "Адрес формы оплаты";
$MESS["SALE_HPS_PAYKEEPER_FORM_URL_DESCR"] = "К примеру, https://<Ваш сайт>.server.paykeeper.ru/create";
$MESS["SALE_HPS_PAYKEEPER_LK_LOGIN"] = "Имя пользователя в личном кабинете PayKeeper";
$MESS["SALE_HPS_PAYKEEPER_LK_LOGIN_DESCR"] = "Логин при регистрации в PayKeeper";
$MESS["SALE_HPS_PAYKEEPER_LK_PASSWORD"] = "Пароль от личного кабинета PayKeeper";
$MESS["SALE_HPS_PAYKEEPER_LK_PASSWORD_DESCR"] = "Пароль при регистрации в PayKeeper";
$MESS["SALE_HPS_PAYKEEPER_SECRET"] = "Секретное слово";

$MESS["SALE_HPS_PAYKEEPER_SETTINGS_PAYMENT"] = "Параметры платёжного обработчика";
$MESS["SALE_HPS_PAYKEEPER_FORM_REDIRECT"] = "Редирект на адрес формы оплаты";
$MESS["SALE_HPS_PAYKEEPER_SBP"] = "Открывать СБП";
$MESS["SALE_HPS_PAYKEEPER_SBP_DESC"] = "Перед использованием этой опции проконсультируйтесь с поддержкой PayKeeper";
$MESS["SALE_HPS_PAYKEEPER_PSTYPE"] = "Тип платёжной системы";
$MESS["SALE_HPS_PAYKEEPER_STATUS_AFTER_PAYMENT"] = "Статус заказа после оплаты";
$MESS["SALE_HPS_PAYKEEPER_REDIRECT_TO_ORDER"] = "Перенаправлять на указанную страницу после оплаты";
$MESS["SALE_HPS_PAYKEEPER_ORDER_PAGE"] = "Страница после оплаты";
$MESS["SALE_HPS_PAYKEEPER_ORDER_PAGE_DESC"] = "Используйте маску #order_id#, автоматически подставляющую номер заказа";
$MESS["SALE_HPS_PAYKEEPER_TRU_CODE_USE"] = "Передавать код ТРУ";
$MESS["SALE_HPS_PAYKEEPER_TRU_CODE_NAME"] = "Обозначение кода ТРУ";
$MESS["SALE_HPS_PAYKEEPER_DISCOUNT_NAME"] = "Принудительный учёт скидок";
$MESS["SALE_HPS_PAYKEEPER_SHIPMENT_NAME"] = "Разрешить отгрузку после оплаты";
$MESS["SALE_HPS_PAYKEEPER_SHIPMENT_DESCR"] = "Если отмечено, то отгрузка заказа будет разрешена автоматически";
$MESS["SALE_HPS_PAYKEEPER_ORDER_CONTACTS_NAME"] = "Запросить контакты по публичной ссылке";
$MESS["SALE_HPS_PAYKEEPER_ORDER_CONTACTS_DESCR"] = "Если отмечено, при использовании публичной ссылки будут запрашиваться ФИО, Email и телефон";
$MESS["SALE_HPS_PAYKEEPER_LOGGING_NAME"] = "Вести лог-файл запросов и ответов";

$MESS["SALE_HPS_PAYKEEPER_SETTINGS_FIRST_CHECK"] = "Настройка первого чека";
$MESS["SALE_HPS_PAYKEEPER_CART_NAME"] = "Передавать корзину";
$MESS["SALE_HPS_PAYKEEPER_CART_DESCR"] = "Если отмечено, то содержимое корзины передаётся по 54-ФЗ";
$MESS["SALE_HPS_PAYKEEPER_VAT_NAME"] = "Ставка НДС товаров по умолчанию";
$MESS["SALE_HPS_PAYKEEPER_VAT_1"] = "НДС не облагается";
$MESS["SALE_HPS_PAYKEEPER_VAT_2"] = "НДС 0%";
$MESS["SALE_HPS_PAYKEEPER_VAT_7"] = "НДС 5%";
$MESS["SALE_HPS_PAYKEEPER_VAT_8"] = "НДС 7%";
$MESS["SALE_HPS_PAYKEEPER_VAT_3"] = "НДС 10%";
$MESS["SALE_HPS_PAYKEEPER_VAT_4"] = "НДС 20%";
$MESS["SALE_HPS_PAYKEEPER_VAT_9"] = "НДС 5/105";
$MESS["SALE_HPS_PAYKEEPER_VAT_10"] = "НДС 7/107";
$MESS["SALE_HPS_PAYKEEPER_VAT_5"] = "НДС 10/110";
$MESS["SALE_HPS_PAYKEEPER_VAT_6"] = "НДС 20/120";
$MESS["SALE_HPS_PAYKEEPER_VAT_PRIORITY_NAME"] = "Приоритет ставки НДС товаров по умолчанию";
$MESS["SALE_HPS_PAYKEEPER_VAT_PRIORITY_DESCR"] = "Если включено, то ставка НДС товаров по умолчанию будет в приоритете";
$MESS["SALE_HPS_PAYKEEPER_BASKET_ITEM_TYPE_NAME"] = "Предмет расчёта для товара";
$MESS["SALE_HPS_PAYKEEPER_BASKET_PAYMENT_TYPE_NAME"] = "Признак расчёта для товара";
$MESS["SALE_HPS_PAYKEEPER_VAT_DELIVERY_NAME"] = "Ставка НДС доставки по умолчанию";
$MESS["SALE_HPS_PAYKEEPER_VAT_DELIVERY_PRIORITY_NAME"] = "Приоритет ставки НДС доставки по умолчанию";
$MESS["SALE_HPS_PAYKEEPER_VAT_DELIVERY_PRIORITY_DESCR"] = "Если включено, то ставка НДС доставки по умолчанию будет в приоритете";
$MESS["SALE_HPS_PAYKEEPER_DELIVERY_ITEM_TYPE_NAME"] = "Предмет расчёта для доставки";
$MESS["SALE_HPS_PAYKEEPER_DELIVERY_PAYMENT_TYPE_NAME"] = "Признак расчёта для доставки";
$MESS["SALE_HPS_PAYKEEPER_ITEM_TYPE_1"] = "Товар";
$MESS["SALE_HPS_PAYKEEPER_ITEM_TYPE_2"] = "Услуга";
$MESS["SALE_HPS_PAYKEEPER_ITEM_TYPE_3"] = "Работа";
$MESS["SALE_HPS_PAYKEEPER_ITEM_TYPE_4"] = "Подакцизный товар";
$MESS["SALE_HPS_PAYKEEPER_ITEM_TYPE_5"] = "Интеллектуальная деятельность, права на интеллектуальную собственность";
$MESS["SALE_HPS_PAYKEEPER_ITEM_TYPE_6"] = "Аванс, задаток, предоплата, взнос или другой платёж";
$MESS["SALE_HPS_PAYKEEPER_ITEM_TYPE_7"] = "Вознаграждение агента";
$MESS["SALE_HPS_PAYKEEPER_ITEM_TYPE_16"] = "О реализуемом товаре, подлежащем маркировке средством идентификации, имеющем код маркировки, за исключением подакцизного товара";
$MESS["SALE_HPS_PAYKEEPER_PAYMENT_TYPE_1"] = "Предоплата 100%";
$MESS["SALE_HPS_PAYKEEPER_PAYMENT_TYPE_2"] = "Частичная предоплата";
$MESS["SALE_HPS_PAYKEEPER_PAYMENT_TYPE_3"] = "Аванс";
$MESS["SALE_HPS_PAYKEEPER_PAYMENT_TYPE_4"] = "Полная оплата в момент передачи предмета расчёта";
$MESS["SALE_HPS_PAYKEEPER_BASKET_MEASURE_NAME"] = "Единица измерения товара";
$MESS["SALE_HPS_PAYKEEPER_MEASURE_1"] = "Штуки или единицы";
$MESS["SALE_HPS_PAYKEEPER_MEASURE_2"] = "Грамм";
$MESS["SALE_HPS_PAYKEEPER_MEASURE_3"] = "Килограмм";
$MESS["SALE_HPS_PAYKEEPER_MEASURE_7"] = "Метр";
$MESS["SALE_HPS_PAYKEEPER_MEASURE_12"] = "Литр";
$MESS["SALE_HPS_PAYKEEPER_CONVERT_FULL_RATES"] = "Преобразовывать полные ставки в расчётные";
$MESS["SALE_HPS_PAYKEEPER_USE_FIXED_NAME_DELIVERY"] = "Указывать в чеке доставку с фиксированным названием позиции";
$MESS["SALE_HPS_PAYKEEPER_FIXED_NAME_DELIVERY"] = "Наименование позиции доставки";

$MESS["SALE_HPS_PAYKEEPER_SETTINGS_SECOND_CHECK"] = "Настройка второго чека";
$MESS["SALE_HPS_PAYKEEPER_PRINT_AFTER_STATUS"] = "Печать чека при статусе заказа";
$MESS["SALE_HPS_PAYKEEPER_PRINT_FINAL_RECEIPT"] = "Включить печать чека окончательного расчёта";

$MESS["SALE_HPS_PAYKEEPER_SETTINGS_HOLD_FUNDS"] = "Холдирование средств";
$MESS["SALE_HPS_PAYKEEPER_ENABLE_EVENT"] = "Включить работу события";
$MESS["SALE_HPS_PAYKEEPER_ENABLE_EVENT_DESC"] = "Перед использованием этой опции проконсультируйтесь с поддержкой PayKeeper";
$MESS["SALE_HPS_PAYKEEPER_ENABLE_CHARGE_PART"] = "Поддержка частичного списания";
$MESS["SALE_HPS_PAYKEEPER_ENABLE_CHARGE_PART_DESC"] = "Включает привязку карты при оплате заказа";
$MESS["SALE_HPS_PAYKEEPER_THRESHOLD_CHARGE_PART"] = "Порог частичного списания (в процентах %)";
$MESS["SALE_HPS_PAYKEEPER_HOLD_AFTER_STATUS"] = "Статус заказа после холдирования";
$MESS["SALE_HPS_PAYKEEPER_DEBIT_AFTER_STATUS"] = "Списание средств при статусе заказа";
$MESS["SALE_HPS_PAYKEEPER_CANCEL_AUTH_AFTER_STATUS"] = "Отмена авторизации при статусе заказа";
$MESS["SALE_HPS_PAYKEEPER_CHARGE_SUCCESS_AFTER_STATUS"] = "Статус заказа после успешного списания";
$MESS["SALE_HPS_PAYKEEPER_CHARGE_FAIL_AFTER_STATUS"] = "Статус заказа после неуспешного списания";

$MESS["SALE_HPS_PAYKEEPER_SETTINGS_ORDER"] = "Параметры заказа";
$MESS["SALE_HPS_PAYKEEPER_ORDER_NUMBER_NAME"] = "Уникальный номер заказа";
$MESS["SALE_HPS_PAYKEEPER_ORDER_NUMBER_DESCR"] = "Этот номер будет отображаться в личном кабинете PayKeeper";
$MESS["SALE_HPS_PAYKEEPER_ORDER_AMOUNT_NAME"] = "Сумма заказа";
?>

==> paykeeper1.5.4_bitrix18-25_rev2.zip: bitrix/modules/sale/handlers/paysystem/paykeeper/lang/ru/.description.php <==
<?php
global $MESS;
$MESS["SALE_HPS_PAYKEEPER_SETTINGS"] = "Настройки подключения PayKeeper";
$MESS["SALE_HPS_PAYKEEPER_FORM_URL"] = "Адрес формы оплаты";
$MESS["SALE_HPS_PAYKEEPER_FORM_URL_DESCR"] = "К примеру, https://<Ваш сайт>.server.paykeeper.ru/create";
$MESS["SALE_HPS_PAYKEEPER_LK_LOGIN"] = "Имя пользователя в личном кабинете PayKeeper";
$MESS["SALE_HPS_PAYKEEPER_LK_LOGIN_DESCR"] = "Логин при регистрации в PayKeeper";
$MESS["SALE_HPS_PAYKEEPER_LK_PASSWORD"] = "Пароль от личного кабинета PayKeeper";
$MESS["SALE_HPS_PAYKEEPER_LK_PASSWORD_DESCR"] = "Пароль при регистрации в PayKeeper";
$MESS["SALE_HPS_PAYKEEPER_SECRET"] = "Секретное слово";

$MESS["SALE_HPS_PAYKEEPER_SETTINGS_PAYMENT"] = "Параметры платёжного обработчика";
$MESS["SALE_HPS_PAYKEEPER_FORM_REDIRECT"] = "Редирект на адрес формы оплаты";
$MESS["SALE_HPS_PAYKEEPER_SBP"] = "Открывать СБП";
$MESS["SALE_HPS_PAYKEEPER_SBP_DESC"] = "Еслю включено, то тип платёжной системы будет передаваться как sbp_default";
$MESS["SALE_HPS_PAYKEEPER_PSTYPE"] = "Тип платёжной системы";
$MESS["SALE_HPS_PAYKEEPER_STATUS_AFTER_PAYMENT"] = "Статус заказа после оплаты";
$MESS["SALE_HPS_PAYKEEPER_REDIRECT_TO_ORDER"] = "Перенаправлять на указанную страницу после оплаты";
$MESS["SALE_HPS_PAYKEEPER_ORDER_PAGE"] = "Страница после оплаты";
$MESS["SALE_HPS_PAYKEEPER_ORDER_PAGE_DESC"] = "Используйте маску #order_id#, автоматически подставляющую номер заказа";
$MESS["SALE_HPS_PAYKEEPER_TRU_CODE_USE"] = "Передавать код ТРУ";
$MESS["SALE_HPS_PAYKEEPER_TRU_CODE_NAME"] = "Обозначение кода ТРУ";
$MESS["SALE_HPS_PAYKEEPER_DISCOUNT_NAME"] = "Принудительный учёт скидок";
$MESS["SALE_HPS_PAYKEEPER_SHIPMENT_NAME"] = "Разрешить отгрузку после оплаты";
$MESS["SALE_HPS_PAYKEEPER_SHIPMENT_DESCR"] = "Если отмечено, то отгрузка заказа будет разрешена автоматически";
$MESS["SALE_HPS_PAYKEEPER_ORDER_CONTACTS_NAME"] = "Запросить контакты по публичной ссылке";
$MESS["SALE_HPS_PAYKEEPER_ORDER_CONTACTS_DESCR"] = "Если отмечено, при использовании публичной ссылки будут запрашиваться ФИО, Email и телефон";
$MESS["SALE_HPS_PAYKEEPER_LOGGING_NAME"] = "Вести лог-файл запросов и ответов";

$MESS["SALE_HPS_PAYKEEPER_SETTINGS_FIRST_CHECK"] = "Настройка первого чека";
$MESS["SALE_HPS_PAYKEEPER_CART_NAME"] = "Передавать корзину";
$MESS["SALE_HPS_PAYKEEPER_CART_DESCR"] = "Если отмечено, то содержимое корзины передаётся по 54-ФЗ";
$MESS["SALE_HPS_PAYKEEPER_VAT_NAME"] = "Ставка НДС товаров по умолчанию";
$MESS["SALE_HPS_PAYKEEPER_VAT_1"] = "НДС не облагается";
$MESS["SALE_HPS_PAYKEEPER_VAT_2"] = "НДС 0%";
$MESS["SALE_HPS_PAYKEEPER_VAT_7"] = "НДС 5%";
$MESS["SALE_HPS_PAYKEEPER_VAT_8"] = "НДС 7%";
$MESS["SALE_HPS_PAYKEEPER_VAT_3"] = "НДС 10%";
$MESS["SALE_HPS_PAYKEEPER_VAT_4"] = "НДС 20%";
$MESS["SALE_HPS_PAYKEEPER_VAT_9"] = "НДС 5/105";
$MESS["SALE_HPS_PAYKEEPER_VAT_10"] = "НДС 7/107";
$MESS["SALE_HPS_PAYKEEPER_VAT_5"] = "НДС 10/110";
$MESS["SALE_HPS_PAYKEEPER_VAT_6"] = "НДС 20/120";
$MESS["SALE_HPS_PAYKEEPER_VAT_PRIORITY_NAME"] = "Приоритет ставки НДС товаров по умолчанию";
$MESS["SALE_HPS_PAYKEEPER_VAT_PRIORITY_DESCR"] = "Если включено, то ставка НДС товаров по умолчанию будет в приоритете";
$MESS["SALE_HPS_PAYKEEPER_BASKET_ITEM_TYPE_NAME"] = "Предмет расчёта для товара";
$MESS["SALE_HPS_PAYKEEPER_BASKET_PAYMENT_TYPE_NAME"] = "Признак расчёта для товара";
$MESS["SALE_HPS_PAYKEEPER_VAT_DELIVERY_NAME"] = "Ставка НДС доставки по умолчанию";
$MESS["SALE_HPS_PAYKEEPER_VAT_DELIVERY_PRIORITY_NAME"] = "Приоритет ставки НДС доставки по умолчанию";
$MESS["SALE_HPS_PAYKEEPER_VAT_DELIVERY_PRIORITY_DESCR"] = "Если включено, то ставка НДС доставки по умолчанию будет в приоритете";
$MESS["SALE_HPS_PAYKEEPER_DELIVERY_ITEM_TYPE_NAME"] = "Предмет расчёта для доставки";
$MESS["SALE_HPS_PAYKEEPER_DELIVERY_PAYMENT_TYPE_NAME"] = "Признак расчёта для доставки";
$MESS["SALE_HPS_PAYKEEPER_ITEM_TYPE_1"] = "Товар";
$MESS["SALE_HPS_PAYKEEPER_ITEM_TYPE_2"] = "Услуга";
$MESS["SALE_HPS_PAYKEEPER_ITEM_TYPE_3"] = "Работа";
$MESS["SALE_HPS_PAYKEEPER_ITEM_TYPE_4"] = "Подакцизный товар";
$MESS["SALE_HPS_PAYKEEPER_ITEM_TYPE_5"] = "Интеллектуальная деятельность, права на интеллектуальную собственность";
$MESS["SALE_HPS_PAYKEEPER_ITEM_TYPE_6"] = "Аванс, задаток, предоплата, взнос или другой платёж";
$MESS["SALE_HPS_PAYKEEPER_ITEM_TYPE_7"] = "Вознаграждение агента";
$MESS["SALE_HPS_PAYKEEPER_ITEM_TYPE_16"] = "О реализуемом товаре, подлежащем маркировке средством идентификации, имеющем код маркировки, за исключением подакцизного товара";
$MESS["SALE_HPS_PAYKEEPER_PAYMENT_TYPE_1"] = "Предоплата 100%";
$MESS["SALE_HPS_PAYKEEPER_PAYMENT_TYPE_2"] = "Частичная предоплата";
$MESS["SALE_HPS_PAYKEEPER_PAYMENT_TYPE_3"] = "Аванс";
$MESS["SALE_HPS_PAYKEEPER_PAYMENT_TYPE_4"] = "Полная оплата в момент передачи предмета расчёта";
$MESS["SALE_HPS_PAYKEEPER_BASKET_MEASURE_NAME"] = "Единица измерения товара";
$MESS["SALE_HPS_PAYKEEPER_MEASURE_1"] = "Штуки или единицы";
$MESS["SALE_HPS_PAYKEEPER_MEASURE_2"] = "Грамм";
$MESS["SALE_HPS_PAYKEEPER_MEASURE_3"] = "Килограмм";
$MESS["SALE_HPS_PAYKEEPER_MEASURE_7"] = "Метр";
$MESS["SALE_HPS_PAYKEEPER_MEASURE_12"] = "Литр";
$MESS["SALE_HPS_PAYKEEPER_CONVERT_FULL_RATES"] = "Преобразовывать полные ставки в расчётные";
$MESS["SALE_HPS_PAYKEEPER_USE_FIXED_NAME_DELIVERY"] = "Указывать в чеке доставку с фиксированным названием позиции";
$MESS["SALE_HPS_PAYKEEPER_FIXED_NAME_DELIVERY"] = "Наименование позиции доставки";

$MESS["SALE_HPS_PAYKEEPER_SETTINGS_SECOND_CHECK"] = "Настройка второго чека";
$MESS["SALE_HPS_PAYKEEPER_PRINT_FINAL_RECEIPT"] = "Включить генерацию чека окончательного расчёта";
$MESS["SALE_HPS_PAYKEEPER_PRINT_FINAL_RECEIPT_DESC"] = "Если включено, то генерация будет происходить при смене статуса заказа";
$MESS["SALE_HPS_PAYKEEPER_PRINT_AFTER_STATUS"] = "Генерация чека при статусе заказа";

$MESS["SALE_HPS_PAYKEEPER_SETTINGS_HOLD_FUNDS"] = "Холдирование средств";
$MESS["SALE_HPS_PAYKEEPER_ENABLE_EVENT"] = "Включить работу события";
$MESS["SALE_HPS_PAYKEEPER_ENABLE_EVENT_DESC"] = "Если включено, то списание будет проводиться при смене статуса заказа";
$MESS["SALE_HPS_PAYKEEPER_ENABLE_CHARGE_PART"] = "Поддержка частичного списания";
$MESS["SALE_HPS_PAYKEEPER_ENABLE_CHARGE_PART_DESC"] = "Используется привязанная карта при списании в большую сторону";
$MESS["SALE_HPS_PAYKEEPER_ENABLE_COF_NEXT"] = "Оплачивать заказы привязанной картой";
$MESS["SALE_HPS_PAYKEEPER_ENABLE_COF_NEXT_DESC"] = "Если включено, то после привязки платежи будут проводиться последней привязанной картой";
$MESS["SALE_HPS_PAYKEEPER_THRESHOLD_CHARGE_PART"] = "Порог частичного списания (в процентах %)";
$MESS["SALE_HPS_PAYKEEPER_THRESHOLD_CHARGE_PART_DESC"] = "Отменяет списание в случае превышения итоговой суммы на указанную величину";
$MESS["SALE_HPS_PAYKEEPER_HOLD_AFTER_STATUS"] = "Статус заказа после холдирования";
$MESS["SALE_HPS_PAYKEEPER_DEBIT_AFTER_STATUS"] = "Списание средств при статусе заказа";
$MESS["SALE_HPS_PAYKEEPER_CANCEL_AUTH_AFTER_STATUS"] = "Отмена авторизации при статусе заказа";
$MESS["SALE_HPS_PAYKEEPER_CHARGE_SUCCESS_AFTER_STATUS"] = "Статус заказа после успешного списания";
$MESS["SALE_HPS_PAYKEEPER_CHARGE_FAIL_AFTER_STATUS"] = "Статус заказа после неуспешного списания";

$MESS["SALE_HPS_PAYKEEPER_SETTINGS_ORDER"] = "Параметры заказа";
$MESS["SALE_HPS_PAYKEEPER_ORDER_NUMBER_NAME"] = "Уникальный номер заказа";
$MESS["SALE_HPS_PAYKEEPER_ORDER_NUMBER_DESCR"] = "Этот номер будет отображаться в личном кабинете PayKeeper";
$MESS["SALE_HPS_PAYKEEPER_ORDER_AMOUNT_NAME"] = "Сумма заказа";
?>
